@@ -318,7 +318,14 @@ to=m.header('To')
 print(to)
 EOF
 	   test_expect_equal_file EXPECTED OUTPUT
-	   ;& # fall through
+	   ;;
+       *)
+	   backup_database
+	   test_begin_subtest ".notmuch without xapian/ handled gracefully ($config)"
+	   rm -r $XAPIAN_PATH
+	   test_expect_success "notmuch new"
+	   restore_database
+	   ;;
    esac
 
    case $config in
